@@ -6,8 +6,7 @@ class Hentai2ReadCom(Provider, Std):
     images_cdn = 'https://static.hentaicdn.com/hentai'
 
     def get_chapter_index(self) -> str:
-        chapter = self.chapter
-        idx = self.re.search('.+/([^/]+)/', chapter)
+        idx = self.re.search('.+/([^/]+)/', self.chapter)
         return '-'.join(idx.group(1).split('.'))
 
     def get_main_content(self):
@@ -17,7 +16,7 @@ class Hentai2ReadCom(Provider, Std):
         return self._get_name(r'\.\w{2,7}/([^/]+)')
 
     def get_chapters(self):
-        return self._elements('li .chapter-row')
+        return self._elements('li .media > a')
 
     def get_files(self):
         content = self.http_get(self.chapter)
@@ -26,11 +25,7 @@ class Hentai2ReadCom(Provider, Std):
         return ['{}{}'.format(self.images_cdn, i) for i in items]
 
     def get_cover(self) -> str:
-        return self._cover_from_content('.ribbon-primary .border-black-op')
-
-    def book_meta(self) -> dict:
-        # todo meta
-        pass
+        return self._cover_from_content('.ribbon-primary a > img')
 
 
 main = Hentai2ReadCom
