@@ -1,7 +1,7 @@
-from .rawdevart_com import RawDevArtCom
+from .rawdevart_com_old import RawDevArtComOld
 
 
-class ISekaiScanCom(RawDevArtCom):
+class ISekaiScanCom(RawDevArtComOld):
     _chapter_selector = r'/chapter-(\d+(?:-[\w\-]+)?)'
 
     def get_files(self):
