@@ -5,14 +5,14 @@ from .helpers.std import Std
 class MangaPandaCom(Provider, Std):
 
     def get_chapter_index(self) -> str:
-        idx = self.re.search(r'\.com/[^/]+/([^/]+)', self.chapter)
+        idx = self.re.search(r'\.\w{2,7}/[^/]+/([^/]+)', self.chapter)
         return idx.group(1)
 
     def get_main_content(self):
         return self._get_content('{}/{}')
 
     def get_manga_name(self) -> str:
-        return self._get_name(r'\.com/([^/]+)')
+        return self._get_name(r'\.\w{2,7}/([^/]+)')
 
     def get_chapters(self):
         return self._elements('#listing a')
