@@ -8,7 +8,7 @@ class MangaXNet(Provider, Std):
     __name = None
 
     def get_chapter_index(self) -> str:
-        re = self.re.compile(r'\.\w+/\w/[^/]+/([^/]+)')
+        re = self.re.compile(r'\.\w{2,7}/\w/[^/]+/([^/]+)')
         return re.search(self.chapter).group(1).replace('.', '-')
 
     def get_main_content(self):
@@ -19,14 +19,14 @@ class MangaXNet(Provider, Std):
         return self.http_get(url)
 
     def get_manga_name(self) -> str:
-        self.__name = self._get_name(r'\.\w+/\w/([^/]+)')
+        self.__name = self._get_name(r'\.\w{2,7}/\w/([^/]+)')
         return unquote_plus(self.__name)
 
     def get_chapters(self):
         return self._elements('.chlist li a')
 
     def get_files(self):
-        ch = self.re.sub(r'(\.\w+)/\w/', r'\1/f/', self.chapter)
+        ch = self.re.sub(r'(\.\w{2,7})/\w/', r'\1/f/', self.chapter)
         parser = self.html_fromstring(ch)
         return self._images_helper(parser, 'img.center-block')
 
