@@ -3,9 +3,6 @@ from .mangago_me import MangaGoMe
 
 class RocacaCom(MangaGoMe):
 
-    def get_archive_name(self) -> str:
-        return self.normal_arc_name(self.get_chapter_index().split('-'))
-
     def get_chapter_index(self) -> str:
         re = self.re.search(r'/.+?chapter-(\d+(?:\.\d+)?)', self.chapter)
         if not re:
